sol.models.rate – Player rates — SoL 3 developers documentation

# `sol.models.rate` – Player rates

class `sol.models.rate.` `Rate`(**kwargs)

  The Glicko rating of a player.

  `caption`(html=None, localized=True)

    A description of the rate.

  `date`

    Rating date.

  `deviation`

    The value of Glicko deviation.

  `idplayer`

    Related `player` ID.

  `idrate`

    Primary key.

  `idrating`

    Related rating’s ID.

  `player`

    The related `player`.

  `rate`

    The value of Glicko rating.

  `serialize`(serializer)

    Reduce a single rate to a simple dictionary.

    Parameters: | serializer – a `Serializer` instance
    Return type: | dict
    Returns: | a plain dictionary containing a flatified view of this rate